@@ -2,7 +2,8 @@ package PDF::WebKit::Source;
 use strict;
 use warnings;
 
-use Moose;
+use Moo;
+use namespace::clean;
 
 has string => ( is => 'rw' );
 
@@ -37,8 +38,5 @@ sub content {
   return ref($self->string) ? ${$self->string} : $self->string;
 }
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
 
